;; Generated package description from org-drill.el  -*- no-byte-compile: t -*-
(define-package "org-drill" "2.7.0" "Self-testing using spaced repetition" '((emacs "25.3") (seq "2.14") (org "9.2.4") (persist "0.3")) :commit "4c114489e682e514e79701045d541ab6f3dc3fb4" :authors '(("Paul Sexton" . "eeeickythump@gmail.com")) :maintainer '("Phillip Lord" . "phillip.lord@russet.org.uk") :keywords '("games" "outlines" "multimedia") :url "https://gitlab.com/phillord/org-drill/issues")
